==> ejc-jltest-impl-3.0.0-20240319.021724-76-sources.jar: com/ejianc/business/jltest/margin/bean/EmployeeDetailsEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 员工明细表 b
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_employee_details")
public class EmployeeDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 员工明细表编码
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="is_stages")
    private String isStages; // 是否分期
    @TableField(value="payable_amount")
    private BigDecimal payableAmount; // 应缴纳金额
    @TableField(value="actual_paid_amount")
    private BigDecimal actualPaidAmount; // 实际已缴纳金额
    @TableField(value="actual_paid_proportion")
    private String actualPaidProportion; // 实际已缴纳比例
    @TableField(value="remaining_payment_amount")
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额

    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getIsStages() {
        return isStages;
    }

    public void setIsStages(String isStages) {
        this.isStages = isStages;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getActualPaidAmount() {
        return actualPaidAmount;
    }

    public void setActualPaidAmount(BigDecimal actualPaidAmount) {
        this.actualPaidAmount = actualPaidAmount;
    }
    public String getActualPaidProportion() {
        return actualPaidProportion;
    }

    public void setActualPaidProportion(String actualPaidProportion) {
        this.actualPaidProportion = actualPaidProportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240328.061301-132-sources.jar: com/ejianc/business/jltest/margin/bean/EmployeeDetailsEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 员工明细表 b
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_employee_details")
public class EmployeeDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 员工明细表编码
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="is_stages")
    private String isStages; // 是否分期
    @TableField(value="payable_amount")
    private BigDecimal payableAmount; // 应缴纳金额
    @TableField(value="actual_paid_amount")
    private BigDecimal actualPaidAmount; // 实际已缴纳金额
    @TableField(value="actual_paid_proportion")
    private String actualPaidProportion; // 实际已缴纳比例
    @TableField(value="remaining_payment_amount")
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    @TableField(value="bill_state")
    private Integer billState; //单据状态

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getIsStages() {
        return isStages;
    }

    public void setIsStages(String isStages) {
        this.isStages = isStages;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getActualPaidAmount() {
        return actualPaidAmount;
    }

    public void setActualPaidAmount(BigDecimal actualPaidAmount) {
        this.actualPaidAmount = actualPaidAmount;
    }
    public String getActualPaidProportion() {
        return actualPaidProportion;
    }

    public void setActualPaidProportion(String actualPaidProportion) {
        this.actualPaidProportion = actualPaidProportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    
}
